pm4py.algo.discovery.correlation\_mining package
================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.correlation_mining.variants

Submodules
----------

pm4py.algo.discovery.correlation\_mining.algorithm module
---------------------------------------------------------

.. automodule:: pm4py.algo.discovery.correlation_mining.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.correlation\_mining.util module
----------------------------------------------------

.. automodule:: pm4py.algo.discovery.correlation_mining.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.correlation_mining
   :members:
   :undoc-members:
   :show-inheritance:
